@@ -2,13 +2,16 @@ from scup.exceptions import (
     ScupPythonError,
     ScupError,
     ScupClientError,
-    HTTPError
+    HTTPError,
+    HTTPTimeoutError
 )
 from scup.scup_api import ScupAPI
 
 __all__ = [
     ScupPythonError,
     ScupError,
+    ScupClientError,
     HTTPError,
+    HTTPTimeoutError,
     ScupAPI
 ]
\ No newline at end of file
