@@ -27,4 +27,7 @@ class ScupClientError(ScupPythonError):
         super(ScupClientError, self).__init__(message)
         
 class HTTPError(ScupPythonError):
-    """ Exception for transport errors. """
\ No newline at end of file
+    """ Exception for transport errors. """
+
+class HTTPTimeoutError(HTTPError):
+    """ Exception for transport timeout errors. """
\ No newline at end of file
